==> highcharts-export-server-0.1.22.tgz: package/tests/stress-test.js <==
/*

Highcharts Export Server

Copyright (c) 2016, Highsoft

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/

const request = require('request');

var sum = 0,
    count = 0,
    options = {
        url: 'http://127.0.0.1:7801',
        headers: {
            'Content-Type': 'application/json'
        },
        method: 'POST',
        body: JSON.stringify({"infile":{"title": {"text": "Steep Chart"}, "xAxis": {"categories": ["Jan", "Feb", "Mar"]}, "series": [{"data": [29.9, 71.5, 106.4]}]}})
    }
;

function doTest(number) {    
    var start = (new Date()).getTime();

    request.post(options,
        function (err, r, res) {
            var t = (new Date()).getTime() - start;
            sum += t;
            if (err) return console.log(number, 'returned error', err);
            count++;
            console.log(number, 'done. took', t, 'ms');          
        }
    );
}

setInterval(function () {
    for (var i = 0; i < 9; i++) {
        doTest(i);
    }    
}, 500);

==> highcharts-export-server-0.1.26.tgz: package/tests/stress-test.js <==
/*

Highcharts Export Server

Copyright (c) 2016, Highsoft

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/

const request = require('request');

var sum = 0,
    count = 0,
    options = {
        url: 'http://127.0.0.1:8081',///?key=AIzaSyAhONZJpMCBqCfQjFUj21cR2klf6JWbVSo&access_token=3074urfkhdfoer',
        headers: {
            'Content-Type': 'application/json'
        },
        method: 'POST',
        body: JSON.stringify({"infile":{"title": {"text": "Steep Chart"}, "xAxis": {"categories": ["Jan", "Feb", "Mar"]}, "series": [{"data": [29.9, 71.5, 106.4]}]}})
    }
;

function doTest(number) {    
    var start = (new Date()).getTime();

    request.post(options,
        function (err, r, res) {
            var t = (new Date()).getTime() - start;
            sum += t;
            if (err) return console.log(number, 'returned error', err);
            count++;
            console.log(number, 'done. took', t, 'ms');          
        }
    );
}

setInterval(function () {
    for (var i = 0; i < 9; i++) {
        doTest(i);
    }    
}, 500);
